Getting Started
===============

Begin your journey with MimiqCircuits. This section guides you through the installation process and provides a high-level tour of the library's main features.

.. grid:: 1 1 2 2
    :gutter: 3

    .. grid-item-card:: :octicon:`download` Installation
        :link: installation
        :link-type: doc

        Step-by-step instructions to set up MimiqCircuits in your Python environment.

    .. grid-item-card:: :octicon:`telescope` Overview
        :link: overview
        :link-type: doc

        A quick tour of what you can do with MimiqCircuits.

.. toctree::
    :maxdepth: 2
    :hidden:

    installation
    overview
